==> vospace-transfer-service-v0.2.2.zip: vospace-transfer-service-v0.2.2/transfer_service/file_grouper.py <==
#!/usr/bin/env python

import os
import shutil
import subprocess
import sys


class FileGrouper(object):

    def __init__(self, minNumOfFiles, maxFolderSize):
        """
        Constructor requiring the minimum number of files
        and the maximum folder size in bytes (constraints).
        """
        self.minNumOfFiles = minNumOfFiles
        self.maxFolderSize = maxFolderSize

    def setMinNumOfFiles(self, minNumOfFiles):
        """Sets the 'minimum number of files' constraint."""
        self.minNumOfFiles = minNumOfFiles
      
    def setMaxFolderSize(self, maxFolderSize):
        """Sets the 'maximum folder size' constraint."""
        self.maxFolderSize = maxFolderSize

    def getLeaves(self):
        """
        Returns a list of all the 'leaves' (directories not
        containing subdirectories) within the path.
        """
        leaves = []
        for root, dirs, files in os.walk(self.folderPath):
            if not dirs:
                leaves.append(root)
        return leaves

    def getFolderSize(self, folder):
        """Returns the folder size in bytes."""
        files = []
        for f in os.listdir(folder):
            files.append(os.path.abspath(folder) + '/' + f)  
        folderSize = 0
        for f in files:
            statinfo = os.stat(f)
            folderSize += statinfo.st_size           
        return folderSize

    def getNumOfFiles(self, folder):
        """Returns the number of files contained into a folder."""
        return len(os.listdir(folder))

    def recursive(self, folderPath):
        """Starts the .tar creation procedure."""
        self.folderPath = folderPath
        leaves = self.getLeaves()
        for folder in leaves:
            if(self.getNumOfFiles(folder) > self.minNumOfFiles and self.getFolderSize(folder) < self.maxFolderSize):
                cwd = os.getcwd()
                parent = os.path.dirname(folder)
                os.chdir(parent)
                sp = subprocess.run(["tar", "-cf", os.path.basename(folder) + ".tar", os.path.basename(folder)], capture_output = True)
                if(sp.returncode or sp.stderr):
                    sys.exit(f"Error: cannot create a .tar for {folder}")
                else:
                    try:
                        shutil.rmtree(folder)
                    except OSError as e:
                        sys.exit(f"Error: {folder} => {e.strerror}")
                os.chdir(cwd)


# Test (creates a .tar of all the leaves containing at least 2 files and having size lower than 100G,
# than removes those directories)
#fg = FileGrouper(1, 100 * (2 ** 30))
#fg.recursive("/home/cristiano/Lavoro/md5_test/store/a")

==> vospace-transfer-service-v0.2.3.zip: vospace-transfer-service-v0.2.3/transfer_service/file_grouper.py <==
#!/usr/bin/env python

import os
import shutil
import subprocess
import sys

from exceptions import TarFileCreationException


class FileGrouper(object):

    def __init__(self, minNumOfFiles, maxFolderSize):
        """
        Constructor requiring the minimum number of files
        and the maximum folder size in bytes (constraints).
        """
        self.minNumOfFiles = minNumOfFiles
        self.maxFolderSize = maxFolderSize

    def setMinNumOfFiles(self, minNumOfFiles):
        """Sets the 'minimum number of files' constraint."""
        self.minNumOfFiles = minNumOfFiles
      
    def setMaxFolderSize(self, maxFolderSize):
        """Sets the 'maximum folder size' constraint."""
        self.maxFolderSize = maxFolderSize

    def getLeaves(self):
        """
        Returns a list of all the 'leaves' (directories not
        containing subdirectories) within the path.
        """
        leaves = []
        for root, dirs, files in os.walk(self.folderPath):
            if not dirs:
                leaves.append(root)
        return leaves

    def getFolderSize(self, folder):
        """Returns the folder size in bytes."""
        files = []
        for f in os.listdir(folder):
            files.append(os.path.abspath(folder) + '/' + f)  
        folderSize = 0
        for f in files:
            statinfo = os.stat(f)
            folderSize += statinfo.st_size           
        return folderSize

    def getNumOfFiles(self, folder):
        """Returns the number of files contained into a folder."""
        return len(os.listdir(folder))

    def recursive(self, folderPath):
        """Starts the .tar creation procedure."""
        self.folderPath = folderPath
        leaves = self.getLeaves()
        for folder in leaves:
            if(self.getNumOfFiles(folder) > self.minNumOfFiles and self.getFolderSize(folder) < self.maxFolderSize):
                cwd = os.getcwd()
                parent = os.path.dirname(folder)
                os.chdir(parent)
                sp = subprocess.run(["tar", "-cf", os.path.basename(folder) + ".tar", os.path.basename(folder)], capture_output = True)
                if(sp.returncode or sp.stderr):
                    raise(TarFileCreationException(folder))
                else:
                    try:
                        shutil.rmtree(folder)
                    except Exception:
                        raise
                os.chdir(cwd)


# Test (creates a .tar of all the leaves containing at least 2 files and having size lower than 100G,
# than removes those directories)
#fg = FileGrouper(1, 100 * (2 ** 30))
#fg.recursive("/home/cristiano/Lavoro/md5_test/store/a")
